package com.cultural.heritage.listener;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.constant.MqConstant;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.model.entity.Coupon;
import com.cultural.heritage.service.good.CouponService;
import com.cultural.heritage.utils.MultiDelayMessage;
import jakarta.annotation.Resource;
import org.springframework.amqp.rabbit.annotation.Exchange;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.QueueBinding;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.stereotype.Component;

@Component
public class CouponStatusListener {


    @Resource
    private CouponService couponService;



    @RabbitListener(bindings = @QueueBinding(
            value = @Queue(MqConstant.DELAY_COUPON_QUEUE),
            exchange = @Exchange(name = MqConstant.DELAY_EXCHANGE, delayed = "true"),
            key = MqConstant.DELAY_COUPON_ROUTING_KEY
    ))
    public void listenDelayMessage(MultiDelayMessage<Long> msg) {
        System.out.println("\n\n\n\n\nCouponStatusListener.listenerDelayMessage msg-------------------------------->：" + msg);

        // 1.获取消息中的优惠券id
        Long couponId = msg.getData();
        // 2.判断优惠券是否存在
        Coupon coupon = couponService.getById(couponId);
        if (coupon == null) {
            return ;
        }
        // 3.更新优惠券状态
        UpdateWrapper<Coupon> updateWrapper = new UpdateWrapper<>();
        updateWrapper.eq("id", couponId).set("status", "已过期");
        boolean update = couponService.update(updateWrapper);
        ThrowUtils.throwIf(!update, ErrorCode.OPERATION_ERROR, "优惠券状态更新失败");

    }


}
